@@ -1,7 +1,7 @@
 package Bencher::Scenario::Serializers;
 
-our $DATE = '2015-10-14'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-10-21'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,6 +59,14 @@ our $scenario = {
             module => 'Pegex::JSON',
             code_template => 'state $obj = Pegex::JSON->new; $obj->load(<data>);',
         },
+        {
+            tags => ['json', 'serialize'],
+            fcall_template => 'JSON::Create::create_json(<data>)',
+        },
+        {
+            tags => ['json', 'deserialize'],
+            fcall_template => 'JSON::Parse::parse_json(<data>)',
+        },
 
         {
             tags => ['yaml', 'serialize'],
@@ -152,6 +160,41 @@ our $scenario = {
             tags => ['serialize'],
             include_participant_tags => ['serialize'],
         },
+        {
+            name => 'array_int100',
+            summary => 'A 100-element array containing ints',
+            args => {data=>[1..100]},
+            tags => ['serialize'],
+            include_participant_tags => ['serialize'],
+        },
+        {
+            name => 'array_int1000',
+            summary => 'A 1000-element array containing ints',
+            args => {data=>[1..1000]},
+            tags => ['serialize'],
+            include_participant_tags => ['serialize'],
+        },
+        {
+            name => 'hash_int10',
+            summary => 'A 10-key hash {1=>0, ..., 10=>0}',
+            args => {data=>{map {$_=>0} 1..10}},
+            tags => ['serialize'],
+            include_participant_tags => ['serialize'],
+        },
+        {
+            name => 'hash_int100',
+            summary => 'A 100-key hash {1=>0, ..., 100=>0}',
+            args => {data=>{map {$_=>0} 1..100}},
+            tags => ['serialize'],
+            include_participant_tags => ['serialize'],
+        },
+        {
+            name => 'hash_int1000',
+            summary => 'A 1000-key hash {1=>0, ..., 1000=>0}',
+            args => {data=>{map {$_=>0} 1..1000}},
+            tags => ['serialize'],
+            include_participant_tags => ['serialize'],
+        },
 
         {
             name => 'json:null',
@@ -180,7 +223,42 @@ our $scenario = {
         {
             name => 'json:array_int10',
             summary => 'A 10-element array containing ints',
-            args => {data=>'[1,2,3,4,5,6,7,8,9,10]'},
+            args => {data=>'['.join(',',1..10).']'},
+            tags => ['deserialize'],
+            include_participant_tags => ['json & deserialize'],
+        },
+        {
+            name => 'json:array_int100',
+            summary => 'A 10-element array containing ints',
+            args => {data=>'['.join(',',1..100).']'},
+            tags => ['deserialize'],
+            include_participant_tags => ['json & deserialize'],
+        },
+        {
+            name => 'json:array_int1000',
+            summary => 'A 1000-element array containing ints',
+            args => {data=>'['.join(',',1..1000).']'},
+            tags => ['deserialize'],
+            include_participant_tags => ['json & deserialize'],
+        },
+        {
+            name => 'json:hash_int10',
+            summary => 'A 10-key hash {"1":0, ..., "10":0}',
+            args => {data=>'{'.join(',', map {qq("$_":0)} 1..10).'}'},
+            tags => ['deserialize'],
+            include_participant_tags => ['json & deserialize'],
+        },
+        {
+            name => 'json:hash_int100',
+            summary => 'A 100-key hash {"1":0, ..., "100":0}',
+            args => {data=>'{'.join(',', map {qq("$_":0)} 1..100).'}'},
+            tags => ['deserialize'],
+            include_participant_tags => ['json & deserialize'],
+        },
+        {
+            name => 'json:hash_int1000',
+            summary => 'A 1000-key hash {"1":0, ..., "1000":0}',
+            args => {data=>'{'.join(',', map {qq("$_":0)} 1..1000).'}'},
             tags => ['deserialize'],
             include_participant_tags => ['json & deserialize'],
         },
@@ -202,7 +280,7 @@ Bencher::Scenario::Serializers - Benchmark Perl data serialization modules
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Serializers (from Perl distribution Bencher-Scenario-Serializers), released on 2015-10-14.
+This document describes version 0.03 of Bencher::Scenario::Serializers (from Perl distribution Bencher-Scenario-Serializers), released on 2015-10-21.
 
 =head1 SYNOPSIS
 
